pub struct FakeDbForStateTest {}Trait Implementations
Sourceimpl Default for FakeDbForStateTest
impl Default for FakeDbForStateTest
Sourcefn default() -> FakeDbForStateTest
fn default() -> FakeDbForStateTest
Returns the “default value” for a type. Read more
Sourceimpl KeyValueDB for FakeDbForStateTest
impl KeyValueDB for FakeDbForStateTest
Sourcefn get_by_prefix(&self, _col: u32, _prefix: &[u8]) -> Result<Option<DBValue>>
fn get_by_prefix(&self, _col: u32, _prefix: &[u8]) -> Result<Option<DBValue>>
Get the first value matching the given prefix.
Sourcefn write(&self, _transaction: DBTransaction) -> Result<()>
fn write(&self, _transaction: DBTransaction) -> Result<()>
Write a transaction of changes to the backing store.
Sourcefn iter<'a>(
&'a self,
_col: u32,
) -> Box<dyn Iterator<Item = Result<DBKeyValue>> + 'a>
fn iter<'a>( &'a self, _col: u32, ) -> Box<dyn Iterator<Item = Result<DBKeyValue>> + 'a>
Iterate over the data for a given column.
Sourcefn iter_with_prefix<'a>(
&'a self,
_col: u32,
_prefix: &'a [u8],
) -> Box<dyn Iterator<Item = Result<DBKeyValue>> + 'a>
fn iter_with_prefix<'a>( &'a self, _col: u32, _prefix: &'a [u8], ) -> Box<dyn Iterator<Item = Result<DBKeyValue>> + 'a>
Iterate over the data for a given column, returning all key/value pairs
where the key starts with the given prefix.
fn transaction(&self) -> DBTransaction
fn transaction(&self) -> DBTransaction
Helper to create a new transaction.